wellformednesstools.Check
=========================

.. inheritance-diagram:: abjad.tools.wellformednesstools.Check.Check.Check
   :private-bases:

.. autoclass:: abjad.tools.wellformednesstools.Check.Check.Check

Methods
-------

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.check

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.report

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.violators

Special Methods
---------------

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__str__

   .. note:: Inherited from `__builtin__.object`
